from django.db import models


class DeleteMixin(models.Model):
    is_deleted = models.BooleanField(default=False, verbose_name='Запись удалена')

    class Meta:
        abstract = True

    def delete(self, using=None, keep_parents=False):
        self.is_deleted = True
        self.save()

    def hard_delete(self):
        super(DeleteMixin, self).delete()



import random
import string


def get_random_string(size=8, chars=string.ascii_uppercase + string.digits):
    """
    Получает случайную строку указанного размера и с указанными символами.
    """
    return ''.join(random.SystemRandom().choice(chars) for _ in range(size))



from django.db import models
from ..managers.active_manager import ActiveManager


class ActiveMixin(models.Model):
    is_active = models.BooleanField(default=True, verbose_name='Включено')
    active_objects = ActiveManager()

    class Meta:
        abstract = True



from django.contrib import admin


class AdminDeleteMixin(admin.ModelAdmin):
    class Meta:
        abstract = True

    def delete_queryset(self, request, queryset):
        for item in queryset:
            item.is_deleted = True
            item.save()

    actions = (
        'hard_delete_queryset',
    )

    def hard_delete_queryset(self, request, queryset):
        for item in queryset:
            item.hard_delete()

    hard_delete_queryset.short_description = 'Удалить из базы данных'



from .active_mixin import ActiveMixin
from .empty_mixin import EmptyMixin
from .delete_mixin import DeleteMixin
from .polymorphic_active_mixin import PolymorphicActiveMixin
from .polymorphic_available_mixin import PolymorphicAvailableMixin
from .available_mixin import AvailableMixin
from .admin_delete_mixin import AdminDeleteMixin
